extensions [ semconarg matrix ]                                                                  ;; extensions used by the model 
;                                                                                                         ;
__includes [ "example_3448d.nls" "have-a-dialog.nls" "network-stuff.nls" ]                                 ;; files included by the model, this is useful to split code into different files
;                                                                                                         ;
globals [                                                                                                 ;; global variables used by the model
  argumentList                                                                                            ;; list of argument labels, like a, b, c, d... n - it's length is defined in each example_number.nls
  polarization                                                                                            ;; gloabal polarization of the world
  density                                                                                                 ;; network density for the caves
  clustering                                                                                              ;; clustering coefficient foe the caves
  trust                                                                                                   ;; trust level in the world
  cave1 cave2 cave3 cave4 cave5 cave6 cave7 cave8 cave9 cave10                                            ;; values of polarization for each
  cave11 cave12 cave13 cave14 cave15 cave16 cave17 cave18 cave19 cave20                                   ;; of the 20 caves
  extensionsPopularity                                                                                    ;; list of all extension types found
  stop-simulation                                                                                         ;; counter for ticks with same polarization value
  old-polarization                                                                                        ;; polarization at time tick - 1 to compare with actual value and see if it has changed
  updated?                                                                                                ;; has polarization value being updated?
  component-size                                                                                          ;; size of the giant component
  already-known-when
  key-known-when
  isolated                                                                                                ;; list of isolated nodes
]                                                                                                         ;; end of global variables
;                                                                                                         ;
turtles-own [                                                                                             ;; agent variables
  first-semantic-extension                                                                                ;; first extension chosen - i.e. first favorite extension
  initial-type                                                                                            ;; which type at setup (1=AF1 vs 2=AF2)
  semantic-extensions                                                                                     ;; a list of semantic extensions like [ [] [a b] [c d e] ]
  favorite-extension                                                                                      ;; the favorite extension chose among the semantic extensions, like [c d e] - it is always the largest one available
  ;; delete this
  trustable                                                                                               ;; probability that a controversial dialog ends with an agent changing their mind
  trustable-initial                                                                                       ;; threshold for trusting initial claim = trustable * .4
  trustable-attack                                                                                        ;; threshold for trusting attack = trustable / (2 * (1 - trustable-initial) )
  trustable-counter                                                                                       ;; threshold for trusting counterattack = 1 - ( (1 - trustable) / ( (1 - trustable-initial) * (1 - trustable-attack) ) )
  ;; end delete this
  AF                                                                                                      ;; the arguments framework
  attacks-received                                                                                        ;; list of attacks received - clear after dialogue
  new-attack                                                                                              ;; agent's reply in dialogue
  my-claim                                                                                                ;; the claim chosen from my favorite extensions
  attacks-told                                                                                            ;; list of attacks told by the agent
  explored?                                                                                               ;; when determining the size of component, flag if an agent has already been explored
]                                                                                                         ;; end of agent variables
;                                                                                                         ;
links-own [ level ]                                                                                       ;; link attribute to discriminate what links to rewire if giant component is required
;                                                                                                         ;
to setup                                                                                                  ;; begin setup procedure
  ca                                                                                                      ;; clear the world
  ;movie-cancel
  ;movie-start "/Users/ogabbrie/Desktop/weaktiesoff.mov"
  ;movie-set-frame-rate 15
  semconarg:initialize                                                                           ;; clear cached values in semanticextensions extension
  initialize-globals                                                                                      ;; initialize global values
  load-example                                                                                            ;; load the example arguments frameworks for agents - this will change depending on the loaded example
  if allow-random-ties? [                                                                                 ;; if weak ties are allowed
    random-rewire                                                                                         ;; add random weak ties
    ask one-of turtles [ explore ]                                                                        ;; as a random turtle to begin exploration
    if single-giant? [                                                                                    ;; if request for single giant component determine size of component.
      giant-component                                                                                     ;; creates one giant component
    ]                                                                                                     ;; end if
  ]                                                                                                       ;; end if
  ;; set extensionsPopularity semanticExtensions:hist-extensions
  set extensionsPopularity semconarg:hist-extensions
  find-polarization                                                                                       ;; find global polarization
  find-density                                                                                            ;; find network density
  find-clustering                                                                                         ;; find caves clustering coefficient
  reset-ticks                                                                                             ;; reset ticks, ready to go
end                                                                                                       ;; end of setup procedure
;                                                                                                         ;
to initialize-globals                                                                                     ;; begin procedure to initialize global variables
  random-seed seed?                                                                                          ;; set the random seed for the experiment
  set polarization 0                                                                                      ;; initialize polarization to 0
  set old-polarization 0                                                                                  ;;
  set already-known-when []
  set key-known-when []
  set updated? false                                                                                      ;;
  set trust 0                                                                                             ;; initialize trust to 0
  set stop-simulation 0                                                                                   ;;
  set extensionsPopularity [[][]]                                                                             ;;
  set component-size 0                                                                                    ;;
  set stop-simulation 0                                                                                   ;;
  set cave1 0 set cave2 0 set cave3 0 set cave4 0 set cave5 0 set cave6 0 set cave7 0 set cave8 0         ;;
  set cave9 0 set cave10 0 set cave11 0 set cave12 0 set cave13 0 set cave14 0 set cave15 0               ;;
  set cave16 0 set cave17 0 set cave18 0 set cave19 0 set cave20 0                                        ;;
  set density 0                                                                                           ;;
  set clustering 0                                                                                        ;;
  set isolated []
end                                                                                                       ;; end global variables procedure
;                                                                                                         ; 
to fill-turtle [ a ]                                                                                      ;; begin fill turtle procedure - takes a parameter, the number of the cave an agent belongs
  set explored? false                                                                                     ;;
  set favorite-extension []                                                                               ;;
  find-semantic-extensions                                                                                ;; initialize semantis extension to empty list
  set first-semantic-extension favorite-extension                                                         ;; save first extension
  set trustable prob-change-mind                                                                          ;; initialize untrustable to 0
  set trustable-initial trustable * .4                                                                    ;;
  set trustable-attack trustable / (2 * (1 - trustable-initial) )                                         ;;
  set trustable-counter 1 - ( (1 - trustable) / ( (1 - trustable-initial) * (1 - trustable-attack) ) )    ;;
  set attacks-received []                                                                                 ;; clear the attacks received list
  set new-attack []                                                                                       ;; clear the new attack list
  set attacks-told []                                                                                     ;; clear the attacks told list
  set size 0.8                                                                                            ;; set agent size
  set shape "person"                                                                                      ;; set agent shape
  set label a                                                                                             ;; set agent group label
end                                                                                                       ;;
;                                                                                                         ;
to find-semantic-extensions                                                                               ;; begin find semantic extension procedure
  set semantic-extensions semconarg:find-ext (matrix:to-row-list AF) selected-semantic          ;; find extensions for this AF
  let maxExt 0
  set favorite-extension []
  foreach semantic-extensions[
    if length ? > maxExt [ set favorite-extension ? set maxExt length ? ]
    if length ? = maxExt [
      ifelse length semantic-extensions = 1 
      [ set favorite-extension ? ]
      [ if random-float 1 < 0.5 [ set favorite-extension ? ] ]
    ]    
  ]
  set color semconarg:set-color favorite-extension semantic-extensions                                                      ;; color agent accordingly
end                                                                                                       ;; end find semantic extension procedure
;                                                                                                         ;; 
to find-polarization                                                                                      ;; begin find global polarization procedure
  set old-polarization polarization                                                                       ;; save old polarization value
  let polarizations semconarg:find-polarization cave-size                                                 ;; retrieve polarizations list
  set polarization precision item 0 polarizations 6                                                       ;; set global polarization value
  set cave1 item 1 polarizations                                                                          ;; set polarization value for this cave
  set cave2 item 2 polarizations                                                                          ;; set polarization value for this cave
  set cave3 item 3 polarizations                                                                          ;; set polarization value for this cave
  set cave4 item 4 polarizations                                                                          ;; set polarization value for this cave
  set cave5 item 5 polarizations                                                                          ;; set polarization value for this cave
  set cave6 item 6 polarizations                                                                          ;; set polarization value for this cave
  set cave7 item 7 polarizations                                                                          ;; set polarization value for this cave
  set cave8 item 8 polarizations                                                                          ;; set polarization value for this cave
  set cave9 item 9 polarizations                                                                          ;; set polarization value for this cave
  set cave10 item 10 polarizations                                                                        ;; set polarization value for this cave
  set cave11 item 11 polarizations                                                                        ;; set polarization value for this cave
  set cave12 item 12 polarizations                                                                        ;; set polarization value for this cave
  set cave13 item 13 polarizations                                                                        ;; set polarization value for this cave
  set cave14 item 14 polarizations                                                                        ;; set polarization value for this cave
  set cave15 item 15 polarizations                                                                        ;; set polarization value for this cave
  set cave16 item 16 polarizations                                                                        ;; set polarization value for this cave
  set cave17 item 17 polarizations                                                                        ;; set polarization value for this cave
  set cave18 item 18 polarizations                                                                        ;; set polarization value for this cave
  set cave19 item 19 polarizations                                                                        ;; set polarization value for this cave
  set cave20 item 20 polarizations                                                                        ;; set polarization value for this cave
  if (old-polarization != polarization)[ set updated? true ]                                              ;; flag if new polarization is different from old value
end                                                                                                       ;; end global polarization procedure
;                                                                                                         ;
to go                                                                                                     ;; begin go procedure
  ifelse (stop-simulation = steps-without-update)                                                         ;; if n steps without polarization changes have passed
  [                                                                                                       ;;
    set already-known-when semconarg:knowledge
    set key-known-when semconarg:evolution
    print already-known-when 
    foreach key-known-when [
      foreach ? [
        let AF-first-last []
        set AF-first-last lput item 0 ? AF-first-last
        let first-last []
        set first-last lput first item 1 ? first-last
        set first-last lput last item 1 ? first-last
        set AF-first-last lput first-last AF-first-last
        print AF-first-last
      ]
    ]
    ;movie-grab-interface 
    ;movie-close
    stop                                                                                                  ;;
  ]                                                                                                       ;; save data to file and stop run
  [                                                                                                       ;; else
    ask turtles [ argue ]                                                                                 ;; each turtle starts arguing with one of its neighbors
    set updated? false                                                                                    ;; set updated? to false
    find-polarization                                                                                     ;; find global polarization value and updates 'updated?'
    set extensionsPopularity semconarg:hist-extensions
    ifelse updated?                                                                                       ;; if new polarization != old polarization
    [ set stop-simulation 0 ]                                                                             ;; reset stop counter
    [ set stop-simulation stop-simulation + 1 ]                                                           ;; else increment stop counter by 1
    tick                                                                                                  ;; advance ticks counter by 1 
    ;movie-grab-interface  
  ]                                                                                                       ;; end else
end                                                                                                       ;; end go procedure
;
; TODO
; - improve the trust mechanism by hacking Skvoretz & Fararo
;
;;; Copyright 2012, Simone Gabbriellini and Paolo Torroni.
;;; Department of Informatics: Science & Engineering (DISI), University of Bologna.
@#$#@#$#@
GRAPHICS-WINDOW
505
11
1168
695
11
11
28.4
1
10
1
1
1
0
0
0
1
-11
11
-11
11
1
1
1
ticks
30.0

SLIDER
14
317
498
350
fract-agents-with-AF1
fract-agents-with-AF1
0
1
0.5
0.01
1
NIL
HORIZONTAL

MONITOR
12
504
126
549
NIL
polarization
6
1
11

BUTTON
278
271
337
304
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
342
271
401
304
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
252
397
499
607
polarization
NIL
NIL
0.0
10.0
0.0
0.0010
true
false
"" ""
PENS
"default" 1.0 0 -7858858 true "" "plot polarization"

SWITCH
15
193
244
226
allow-random-ties?
allow-random-ties?
0
1
-1000

MONITOR
133
506
243
551
NIL
density
4
1
11

MONITOR
12
454
244
499
NIL
clustering
4
1
11

CHOOSER
15
140
245
185
selected-semantic
selected-semantic
"admissible" "complete" "ideal" "grounded" "preferred" "stable" "semi-stable"
1

MONITOR
254
11
311
56
NIL
cave1
4
1
11

MONITOR
317
11
374
56
NIL
cave2
4
1
11

MONITOR
379
11
436
56
NIL
cave3
4
1
11

MONITOR
440
11
497
56
NIL
cave4
4
1
11

MONITOR
254
61
311
106
NIL
cave5
4
1
11

MONITOR
318
61
375
106
NIL
cave6
4
1
11

MONITOR
379
60
436
105
NIL
cave7
4
1
11

MONITOR
440
61
497
106
NIL
cave8
4
1
11

MONITOR
253
111
310
156
NIL
cave9
4
1
11

MONITOR
317
110
374
155
NIL
cave10
4
1
11

MONITOR
379
110
436
155
NIL
cave11
4
1
11

MONITOR
440
110
497
155
NIL
cave12
4
1
11

MONITOR
253
160
310
205
NIL
cave13
4
1
11

MONITOR
316
161
373
206
NIL
cave14
4
1
11

MONITOR
380
161
437
206
NIL
cave15
4
1
11

MONITOR
441
162
498
207
NIL
cave16
4
1
11

MONITOR
252
209
309
254
NIL
cave17
4
1
11

MONITOR
316
210
373
255
NIL
cave18
4
1
11

MONITOR
379
211
436
256
NIL
cave19
4
1
11

MONITOR
441
211
498
256
NIL
cave20
4
1
11

PLOT
1178
17
1551
272
extensions popularity
ext
popularity
0.0
140.0
0.0
10.0
true
false
"; [] 0\n; [\"a\"] 1\n; [\"b\"] 2\n; [\"c\"] 3\n; [\"d\"] 4\n; [\"e\"] 5\n; [\"a\" \"b\"] 6\n; [\"a\" \"c\"] 7\n; [\"a\" \"d\"] 8\n; [\"a\" \"e\"] 9\n; [\"b\" \"c\"] 10\n; [\"b\" \"d\"] 11\n; [\"b\" \"e\"] 12\n; [\"c\" \"d\"] 13\n; [\"c\" \"e\"] 14\n; [\"d\" \"e\"] 15\n; [\"a\" \"b\" \"c\"] 16\n; [\"a\" \"b\" \"d\"] 17\n; [\"a\" \"b\" \"e\"] 18\n; [\"a\" \"c\" \"d\"] 19\n; [\"a\" \"c\" \"e\"] 20\n; [\"a\" \"d\" \"e\"] 21\n; [\"b\" \"c\" \"d\"] 22\n; [\"b\" \"c\" \"e\"] 23\n; [\"b\" \"d\" \"e\"] 24\n; [\"c\" \"d\" \"e\"] 25\n; [\"a\" \"b\" \"c\" \"d\"] 26 \n; [\"a\" \"b\" \"c\" \"e\"] 27\n; [\"a\" \"b\" \"d\" \"e\"] 28\n; [\"a\" \"c\" \"d\" \"e\"] 29\n; [\"b\" \"c\" \"d\" \"e\"] 30\n; [\"a\" \"b\" \"c\" \"d\" \"e\"] 31" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram item 0 extensionsPopularity"

SLIDER
13
357
498
390
prob-change-mind
prob-change-mind
0.2
0.8
0.5
0.1
1
NIL
HORIZONTAL

SWITCH
15
232
244
265
single-giant?
single-giant?
0
1
-1000

MONITOR
12
403
243
448
size of giant component
component-size
17
1
11

MONITOR
12
557
243
602
steps without update
stop-simulation
17
1
11

BUTTON
408
271
471
304
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
15
10
123
70
cave-size
5
1
0
Number

PLOT
1180
280
1554
545
favorite extension popularity
NIL
NIL
0.0
140.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram item 1 extensionsPopularity"

INPUTBOX
15
74
244
134
steps-without-update
500
1
0
Number

SWITCH
14
272
243
305
exact-AF1-AF2-proportion?
exact-AF1-AF2-proportion?
0
1
-1000

INPUTBOX
132
10
244
70
seed?
123456789
1
0
Number

@#$#@#$#@
## WHAT IS IT?

_(a general understanding of what the model is trying to show or explain)_

    prova di codice

1. prova di lista
* prova di unordered

> disclaimer
> tutto

prova di `ask turtle [fwd 1]` in lines

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

The model works up to 10 arguments. 10 is a natural limit since we use powersets, and values exceeding this limit are computationally too slow or even untractable. Despite of this limitation, we believe that 10 is a reasonably number of arguments for one single discussion: is very improbable that persons can handle a debate with much more arguments, but we need to confront this value with results obtained by COGITO and empirical online data.
Each agent selects an argument from its favorite extension, i.e. the largest extension available among its semantic extension. This is to allow for having tolerant agents that believe in the largest set of arguments they have.
Polarization is then calculated as the variance of the favorite extension that each agent select among the possible semantic extensions, given the argumentative framework.

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

The model uses an extension called SemanticExtensions, which computes semantic extensions of the turtles' argumentation frameworks. Each framework is represented as a built-in matrix, using the Matrix extensions. Suppose to have four arguments, where argument "a" attacks argument "b", argument "b" attacks argument "c" and argument "c" attacks argument "d". The complete semantic extension of this argumentation framework is "[a c]" and its representation as a matrix is as follows:

    First argumentation          Second argumentation
    framework                    framework
      a b c d                      a b c d
    a 0 1 0 0                    a 0 0 0 0
    b 0 0 1 0                    b 0 0 1 0
    c 0 0 0 1                    c 0 0 0 1
    d 0 0 0 0                    d 1 0 0 0

These two argumentation framework are a fixed starting point for the model. They can be changed in the Code tab, by using different matrices values.

## RELATED MODELS

* Flache and Macy, "Small World and Cultural Polarization", Journal of Mathematical Sociology
* Skvoretz and Fararo, "", American Journal of Sociology

## CREDITS AND REFERENCES

Copyright 2012 by Simone Gabbriellini and Paolo Torroni
Department of Informatics: Science & Engineering
University of Bologna

Send email to: simone.gabbriellini@unibo.it
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="new experiment" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>polarization                 ;; polarization level</metric>
    <metric>ticks                        ;; time</metric>
    <metric>item 1 extensionsPopularity  ;; initial favorite extensions</metric>
    <metric>prob-change-mind             ;; level of trust</metric>
    <metric>count links with [level = 1] ;; # weak ties</metric>
    <metric>isolated                     ;; # of isolated</metric>
    <enumeratedValueSet variable="allow-random-ties?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="single-giant?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="n-agents-with-AF1" first="0.2" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="prob-change-mind">
      <value value="0.2"/>
      <value value="0.5"/>
      <value value="0.8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="tipping-point" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>polarization</metric>
    <enumeratedValueSet variable="semantic">
      <value value="&quot;complete&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="attack-prob" first="0.1" step="0.1" last="0.9"/>
    <steppedValueSet variable="trust-other" first="0.2" step="0.3" last="0.8"/>
    <enumeratedValueSet variable="random?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="single-giant?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
